#-----------------------------------------------------------
# @(#) siemens-bss/tech_pack_support/Siemens_BSS/BR8/EngineConfig.pm siemens-bss_r3.1.0.4:cset.002618:8:8@(#)
#-----------------------------------------------------------
#
# This perl module contains the configuration information 
# for this parser. If you don't understand the format of 
# this configuration file DON'T TOUCH IT.
#
# EngineConfig.pm
# 
#  Copyright (C) 2007 Vallent Software Systems UK. All rights reserved.

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();

#-------------------------------------------------------------------------------



#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = 
    (
     {
         RULE_TYPE => 'SIEMENS_ACL',
         RULE_DESC => 'Process OMC MML create command',
         INPUT_FILE_DESCRIPTION => [ '\w+\.acl\..*$' ],
         INPUT_DIR_DEPTH => 0,
         FILENAME_HEADER_FIELDS => {
             ID => '^(\w+)\.acl\..*',
         },
         COMMAND_COUNTERS_FOR_HEADER => [ qw (NAMEBSC) ],
         COMMAND_CONFIG => 
         {
             PCU => {
                 KEEP_COUNTERS => [ qw(NAME.* NSEI) ],
             },
             NSVC => {
                 KEEP_COUNTERS => [ qw(NAME.* NSVCI NSVLI) ],
                 MANIP_COUNTERS => {
                     NSVLI => '\d+-(\d+)',
                 }
             },
             FRL => {
                 KEEP_COUNTERS => [ qw(NAME.* PCUN GTS) ],
             },
             PTPPKF => {
                 NEW_COUNTERS => { 
                     NAMEBTS => [ "NAMEPTPPKF"  ], 
                 },
                 KEEP_COUNTERS => [ qw(NAMEBSC NAMEBTS PCUN RACODE) ],
             },
             BTS_PKGBTSB => {
                 KEEP_COUNTERS => [ qw(NAME.* CELLTYPE CONCELL BCCHFREQ) ],
             },
             TRX => {
                 KEEP_COUNTERS => [ qw(NAME.* TRXFREQ TRX_ID) ],  
             },
             CHAN => {
                 KEEP_COUNTERS => [ qw(NAME.* CHTYPE GCCH) ],
             },       
             ADJC => {
                 KEEP_COUNTERS => [ qw(NAME.* TGTCELLREF CELLGLID BSIC TGTCELL) ],
                 IGNORE_COUNT  => 'True',
             }	     
         },
         
     },
     {
         RULE_TYPE  => "SIEMENS_BSS",
         RULE_DESC  => "Parse siemens BR6 performance data",
         INPUT_FILE_DESCRIPTION => ['^B\w+_\d+[\._]\d{14}[\._]\d{14}-\d{3}\.ASCII.*'],
         NUMBER_OF_FILES_TO_PROCESS => 24,
         ORDER_OF_FILES                  => 'OLDEST_FIRST',
         FILENAME_HEADER_FIELDS => {
             BSS_ID => '^B\w+_(\d+)[\._]\d{14}[\._]\d{14}-\d{3}\.ASCII.*',
             #STARTDATE => '^B\w+_\d+[\._](\d{8})',
             #ENDDATE => '^B\w+_\d+[\._]\d{14}[\._](\d{8})',
         },
         HEADER_FIELDS_FOR_PIF_FILENAME =>  [ qw (BSS_ID BSC_ID) ],
         DEFAULT_NULL_VALUE => 'NULL',
	 ENABLE_FILENAME_TIMESTAMP => 'True',
	 ENABLE_FILENAME_COUNTER => 'True',
         MONITORED_OBJECTS => {
             bsc =>    [ qw (BSC_ID BTSM_ID) ],
             bts =>    [ qw (BSC_ID BTSM_ID BTS_ID) ],
             trx =>    [ qw (BSC_ID BTSM_ID BTS_ID TRX_ID) ],
             chan =>   [ qw (BSC_ID BTSM_ID BTS_ID TRX_ID CHAN) ],
             ss7l =>   [ qw (BSC_ID LINKSET) ],
             tgtbts => [ qw (BTSM_ID BTS_ID) ],
             btsm =>   [ qw (BSC_ID BTSM_ID) ],
             tgtfdd => [ qw(BTSM_ID FDD_NO) ],
	     ptppkf => [ qw(BSC_ID BTSM_ID BTS_ID PTPPKF_ID) ]
         },
         OUTPUT_MEASURE_IDENTIFIER => 0,
         KEEP_VALIDITY_VALUES => ['0', '1', '2', '3'],
         IGNORE_INVALID_VALUES => 0,
         ENABLE_PIF_CACHE      => "True",
         OBJECT_CLASSES => {
             SCANBSC => {
                 CLASS => 0,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANBTS => {
                 CLASS => 1,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 OPTIONAL_VALUE_COUNTER => 'CELLTYPE',
                 OPTIONAL_COUNTER_AS_PIF_KEY => 'True',
             },
             SCANBTSE => {
                 CLASS => 2,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 OPTIONAL_VALUE_COUNTER => 'CELLTYPE',
             },
             SCANBTSIHO => {
                 CLASS => 3,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
            },
             SCANBTSM => {
                 CLASS => 4,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANBTSOHOI => {
                 CLASS => 5,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANBTSOHON => {
                 CLASS => 6,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANCHAN => {
                 CLASS => 7,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 OPTIONAL_VALUE_COUNTER => 'CHANNEL_SEL_BYTES',
                 OPTIONAL_COUNTER_AS_ROW_KEY => "True",
             },
             SCANCTRX_CRXLVQUU => {
                 CLASS => 8,
                 MEASUREMENT_LIST => 0,
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 INSERT_COUNTERS => {
                     LINKTYPE => "UPLINK",
                 },
             },
             SCANCTRX_CRXLVQUD => {
                 CLASS => 8,
                 MEASUREMENT_LIST => 1,
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 INSERT_COUNTERS => {
                     LINKTYPE => "DOWNLINK",
                 },
             },
             SCANCTRX_CRXLVTAU => {
                 CLASS => 8,
                 MEASUREMENT_LIST => 2,
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 INSERT_COUNTERS => {
                     LINKTYPE => "UPLINK",
                 },
             },
             SCANCTRX_CRXLVTAD => {
                 CLASS => 8,
                 MEASUREMENT_LIST => 3,
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 INSERT_COUNTERS => {
                     LINKTYPE => "DOWNLINK",
                 },
             },
             SCANCTRX_CFERRXQU => {
                 CLASS => 8,
                 MEASUREMENT_LIST => 4,
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANGPRS => {
                 CLASS => 9,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
            },
             SCANSS7L => {
                 CLASS => 10,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
                 OPTIONAL_VALUE_COUNTER => 'CHANNEL_SEL_BYTES',
             },
             SCANTRX => {
                 CLASS => 11,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANBTSOHOS => {
                 CLASS => 12,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },
             SCANFBTSM => {
                 CLASS => 13,
                 MEASUREMENT_LIST => '*',
                 MONITORED_OBJECTS_KEYS => [ qw(BSC_ID) ],
             },

         },
     }
         
);  


sub engine_config {
    return \@rules;
}

1;
