

#-------------------------------------------------------------------------------
# @(#) siemens-bss/tech_pack_support/Siemens_BSS/BR8/UserConfig.pm siemens-bss_r3.1.0.4:cset.002621:10:10@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
#
#  Copyright (C) 2007 Vallent Software Systems UK. All rights reserved.
#
package UserConfig;

# Company Name: 

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();
use AudLog;

#-------------------------------------------------------------------------------


my @rules = 
    (
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
     # count the number of channels per BTS
           {
               RULE_TYPE => 'FILE_SPLIT',
               RULE_DESC => 'Split SCANBTS according to cell type',
               INPUT_FILE_DESCRIPTION => ['^SCANBTS-#-.*-#-I\.pif$'],
               COUNTERS_USED_TO_SPLIT_FILE => {
                                              CELLTYPE => '^(\d+)',
                                           },
               SPLIT_COUNTERS_ORDER     => [  qw(CELLTYPE)  ],
               OUTPUT_BLOCK_NAME      => 'SCANBTS',
               OUTPUT_FORMAT          => 0,
               PRODUCE_PIF	           => 'True',
           },    
           {
               RULE_TYPE               => 'ACCUMULATE',
               RULE_DESC               => 'Accumulate SCANBTS HO  aggregated values over Target CELL',
               INPUT_FILE_DESCRIPTION  => ['^SCANBTSOHON-#-\d+-#-\d+-#-(.*)-#-\d+-#-.*-#-I\.pif',
                                           '^SCANBTSIHO-#-\d+-#-\d+-#-(.*)-#-\d+-#-.*-#-I\.pif',
                                           '^SCANBTSOHOS-#-\d+-#-\d+-#-(.*)-#-\d+-#-.*-#-I\.pif',
                                           '^SCANBTSOHOI-#-\d+-#-\d+-#-(.*)-#-\d+-#-.*-#-I\.pif'],
               COUNTERS_TO_SORT_ON     => [qw(CEL_ID)],
               #REDUNDANT_COUNTERS      => [qw(ADJ_BTSM_ID ADJ_CELL_ID ADJ_BSC_ID ADJ_BTS_ID)],
               NON_ADDITIVE_COUNTERS   => [qw(BTSM_ID BTS_ID ADJ_BSC_ID ADJ_BTS_ID ADJ_BTSM_ID ADJ_CELL_ID)],
               OUTPUT_BLOCK_NAME       => 'AGGREGATE',
               PRODUCE_PIF             => "True",
               PRODUCE_LIF             => 0
           },

          {
               RULE_TYPE => 'AGGREGATE_LINE',
               RULE_DESC => 'Aggregate C3 Counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTSIHO-#-.*-#-AGGREGATE-#-A.pif'],
               REDUNDANT_DATA_COUNTERS => [],
               DEFAULT_NULL_VALUE => '0',
               COUNTER_GROUPS => {
                  C3_1_AGGREGATE_TOTAL => 'C3_1_.*',
                  C3_0_AGGREGATE_TOTAL => 'C3_0_.*',
               },
           },

           {
               RULE_TYPE              => 'PIF_2_OUTPUT',
               RULE_DESC              => 'Output Accumulated SCANBTSIHO LIFs',
               INPUT_FILE_DESCRIPTION => ['^SCANBTSIHO-#-.*-#-AGGREGATE-#-A-#-AL.pif'],
               OUTPUT_FILENAME_START  => 'SCANBTSIHO_AGGREGATE',
               OUTPUT_BLOCK_NAME      => 'SCANBTSIHO_AGGREGATE',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
           },

          {
               RULE_TYPE => 'AGGREGATE_LINE',
               RULE_DESC => 'Aggregate C5 Counters',
               INPUT_FILE_DESCRIPTION => ['^SCANBTSOHOI-#-.*-#-AGGREGATE-#-A.pif'],
               REDUNDANT_DATA_COUNTERS => [],
               DEFAULT_NULL_VALUE => '0',
               COUNTER_GROUPS => {
                  C5_1_AGGREGATE_TOTAL => 'C5_1_.*',
                  C5_0_AGGREGATE_TOTAL => 'C5_0_.*',
                  ATT_UL_QUALITY => 'C5_1_(1|12|23|34)',
                  ATT_DL_QUALITY => 'C5_1_(2|13|24|35)',
                  ATT_UL_STRENGTH => 'C5_1_(3|14|25|36)',
                  ATT_DL_STRENGTH => 'C5_1_(4|15|26|37)',
                  ATT_DISTANCE => 'C5_1_(5|16|27|38)',
                  ATT_BETTER_CELL => 'C5_1_(6|17|28|39)',
                  ATT_DIRECTED_RET => 'C5_1_(7|18|29|40)',
                  ATT_FORCED_OM => 'C5_1_(8|19|30|41)',
                  ATT_TRAFFIC => 'C5_1_(9|20|31|42)',
                  ATT_FAST_UL => 'C5_1_(10|21|32|43)',
                  ATT_FORCED_PRE => 'C5_1_(11|22|33|44)',
                  SUC_UL_QUALITY => 'C5_0_(1|12|23|34)',
                  SUC_DL_QUALITY => 'C5_0_(2|13|24|35)',
                  SUC_UL_STRENGTH => 'C5_0_(3|14|25|36)',
                  SUC_DL_STRENGTH => 'C5_0_(4|15|26|37)',
                  SUC_DISTANCE => 'C5_0_(5|16|27|38)',
                  SUC_BETTER_CELL => 'C5_0_(6|17|28|39)',
                  SUC_DIRECTED_RET => 'C5_0_(7|18|29|40)',
                  SUC_FORCED_OM => 'C5_0_(8|19|30|41)',
                  SUC_TRAFFIC => 'C5_0_(9|20|31|42)',
                  SUC_FAST_UL => 'C5_0_(10|21|32|43)',
                  SUC_FORCED_PRE => 'C5_0_(11|22|33|44)',
               },
           },

           {
               RULE_TYPE              => 'PIF_2_OUTPUT',
               RULE_DESC              => 'Output Accumulated SCANBTSOHOI LIFs',
               INPUT_FILE_DESCRIPTION => ['^SCANBTSOHOI-#-.*-#-AGGREGATE-#-A-#-AL.pif'],
               OUTPUT_BLOCK_NAME      => 'SCANBTSOHOI_AGGREGATE',
               PRODUCE_PIF            => 0,
               OUTPUT_FORMAT          => "LIF_Writer"
           },
           {
               RULE_TYPE              => 'PIF_2_OUTPUT',
               RULE_DESC              => 'Output Accumulated SCANBTSOHON LIFs',
               INPUT_FILE_DESCRIPTION => ['^SCANBTSOHON-#-.*-#-AGGREGATE-#-A.pif'],
               OUTPUT_BLOCK_NAME      => 'SCANBTSOHON_AGGREGATE',
               PRODUCE_PIF            => 0,
               OUTPUT_FORMAT          => "LIF_Writer"
           }, 
           {
               RULE_TYPE              => 'PIF_2_OUTPUT',
               RULE_DESC              => 'Output Accumulated SCANBTSOHOS LIFs',
               INPUT_FILE_DESCRIPTION => ['^SCANBTSOHOS-#-.*-#-AGGREGATE-#-A.pif'],
               OUTPUT_BLOCK_NAME      => 'SCANBTSOHOS_AGGREGATE',
               PRODUCE_PIF             => 0,
               OUTPUT_FORMAT           => "LIF_Writer"
           },
	   	   {
	       RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Output SCANBTS STANDARD LIFs',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-#-\d+-#-\d+-#-.*-#-\d+-#-0-#-.*-#-FS\.pif$'],
               OUTPUT_FILENAME_START  => 'SCANBTS_STANDARD',
               OUTPUT_BLOCK_NAME      => 'SCANBTS_STANDARD',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
	   },
           {
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Output SCANBTS CONCENTRIC LIFs',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-#-\d+-#-\d+-#-.*-#-\d+-#-1-#-.*-#-FS\.pif$'],
               OUTPUT_FILENAME_START  => 'SCANBTS_CONCENTRIC',
               OUTPUT_BLOCK_NAME      => 'SCANBTS_CONCENTRIC',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
           },
           {
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Output SCANBTS EXTENDED LIFs',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-#-\d+-#-\d+-#-.*-#-\d+-#-2-#-.*-#-FS\.pif$'],
               OUTPUT_FILENAME_START  => 'SCANBTS_EXTENDED',
               OUTPUT_BLOCK_NAME      => 'SCANBTS_EXTENDED',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
           },
	              {
               RULE_TYPE => 'PERLIZE',
               RULE_DESC => 'Rename SCANBTSOHON_AGGREGATE counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTSOHON-#-.*-#-PM-#-.*-#-I-#-AGGREGATE-#-A\.pif$'],
               DATA_COUNTERS_OP       => sub {
               my $d_ref = shift;

                   foreach my $cname (grep {/C6_/} keys %{$d_ref}) {
                       my $cname_new = $cname;
                       $cname_new .= '_SCANBTSOHON_AGGREGATE';
                       $d_ref->{$cname_new} = $d_ref->{$cname};
                       delete $d_ref->{$cname};
                   }

                   return 0;
               },
               OUTPUT_BLOCK_NAME      => 'SCANBTSOHON_AGGREGATE',
               FILENAME_SUFFIX        => 'PZ',
               OUTPUT_FORMAT          => 0,
               PRODUCE_PIF            => 'True',
          }, 
          {
               RULE_TYPE => 'PERLIZE', 
               RULE_DESC => 'Rename SCANBTSOHOS_AGGREGATE counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTSOHOS-#-.*-#-PM-#-.*-#-I-#-AGGREGATE-#-A\.pif$'],
               DATA_COUNTERS_OP       => sub {
                   my $d_ref = shift;
			
                   foreach my $cname (grep {/C12_/} keys %{$d_ref}) {
                       my $cname_new = $cname;
                       $cname_new .= '_SCANBTSOHOS_AGGREGATE';
                       $d_ref->{$cname_new} = $d_ref->{$cname};
                       delete $d_ref->{$cname};
                   }

                   return 0;
               },
               OUTPUT_BLOCK_NAME      => 'SCANBTSOHOS_AGGREGATE',
               FILENAME_SUFFIX        => 'PZ',
               OUTPUT_FORMAT          => 0,
               PRODUCE_PIF            => 'True',
          },
	  {
               RULE_TYPE => 'JOIN',
               RULE_DESC => 'Join SCANBTS',
               INPUT_FILE_DESCRIPTION => [
							      'SCANBTS-#-(.*)-#-\d+-#-0-#-PM-#-.*-#-I\.pif',
							      'SCANBTS-#-(.*)-#-\d+-#-1-#-PM-#-.*-#-I\.pif',
							      'SCANBTS-#-(.*)-#-\d+-#-2-#-PM-#-.*-#-I\.pif',
                                                 ], 
               OUTPUT_BLOCK_NAME      => 'SCANBTS',
               PRODUCE_PIF            => 'True',
               PRODUCE_LIF            => 0,   
               COUNTERS_TO_JOIN_ON    => [qw(BTS_ID BTSM_ID CEL_ID)],
               HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
               OUTPUT_FILENAME_START           => 'SCANBTS',
	       HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ["BSS_ID", "BSC_ID", "ENDDATE", "ENDTIME", "BSC_ID" ],
           },

           {
		RULE_TYPE	=> 'FILE_SPLIT_BY_COUNTERS',
		RULE_DESC	=> 'Split the counters',
		INPUT_FILE_DESCRIPTION => ['SCANBTS-#-.*-#-J\.pif$'],
		SPLIT_CNAMES		=> {
			'1' => ['C1_0_[1-4]'],
		},
		ONLY_INSERT => [ qw(BTS_ID BTSM_ID CEL_ID ADJ_BTS_ID ADJ_BTSM_ID ADJ_CEL_ID) ],
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
           },


	   {
		RULE_TYPE              => 'ACCUMULATE',
		RULE_DESC              => 'Accumulate SCANBTS to BSC',
		INPUT_FILE_DESCRIPTION => ['SCANBTS-#-.*-#-FSC\.pif$'],
		OUTPUT_BLOCK_NAME      => 'BTS_AGG_TO_BSC',
		COUNTERS_TO_SORT_ON    => [qw(BSC_ID)],
		OLD_COUNTER_NAMES      => ['C1_0_1','C1_0_2','C1_0_3','C1_0_4'],
		NEW_COUNTER_NAMES      => ['MEBUSTCH1','MEBUSTCH2','MEBUSTCH3','MEBUSTCH4'],
		NON_ADDITIVE_COUNTERS  => ['ADJ_CEL_ID', 'ADJ_BTSM_ID', 'ADJ_BTS_ID', 'BTSM_ID', 'BTS_ID', 'CEL_ID'],
		PRODUCE_PIF            => 0,
		PRODUCE_LIF            => 'True',
		OUTPUT_FORMAT	=> 'LIF_Writer',
	   },
#	   {
#		RULE_TYPE => 'FILE_SPLIT',
#               RULE_DESC => 'Split DEBUG',
#               INPUT_FILE_DESCRIPTION => ['^SCANBTS-#-.*-#-J\.pif$'],
#               COUNTERS_USED_TO_SPLIT_FILE => {
#                                              CEL_ID => '(.*)', 
#                                           },
#               SPLIT_COUNTERS_ORDER     => [ qw(CEL_ID) ], 
#               OUTPUT_BLOCK_NAME      => 'SCANBTS',
#               OUTPUT_FORMAT          => 'LIF_Writer',
#               PRODUCE_PIF            => 0,   
#	       PRODUCE_LIF 		=> 'True',
#	   },

           {
               RULE_TYPE => 'INFOINSERT',
               RULE_DESC => 'Add some HO aggregate counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-#-(.*)-#-\d+-#-.*J\.pif'], 
               HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],               
               NAMES_USED_TO_ID_DATA_RECORD => ['CEL_ID'],
               INFO_FILE_DESCRIPTION => ['^SCANBTSOHON-.*-PZ\.pif'],
               HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
               NAMES_USED_TO_ID_INFORMATION => ['CEL_ID'],
               OUTPUT_BLOCK_NAME => 'SCANBTS',
               REDUNDANT_DATA_COUNTERS => [],
               ONLY_INSERT => ['C6_1_7_SCANBTSOHON_AGGREGATE'],
               WRITE_DATA_LINE => 'True',
               PRODUCE_PIF => 'True',
               PRODUCE_LIF => 0,
        },
        {
               RULE_TYPE => 'INFOINSERT',
               RULE_DESC => 'Add some HO aggregate counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-#-(.*)-#-\d+-#-.*J-#-S\.pif'], 
               HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],               
               NAMES_USED_TO_ID_DATA_RECORD => ['CEL_ID'],
               INFO_FILE_DESCRIPTION => ['^SCANBTSOHOS-.*-PZ\.pif'],
               HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
               NAMES_USED_TO_ID_INFORMATION => ['CEL_ID'],
               OUTPUT_BLOCK_NAME => 'SCANBTS',
               REDUNDANT_DATA_COUNTERS => [],
               ONLY_INSERT => ['C12_1_7_SCANBTSOHOS_AGGREGATE'],
               WRITE_DATA_LINE => 'True',
               PRODUCE_PIF => 'True',
               PRODUCE_LIF => 0,
        },

          {
               RULE_TYPE => 'AGGREGATE_LINE', 
               RULE_DESC => 'Add HO Counters',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-.*-#-J-#-S-#-S\.pif$'],
               REDUNDANT_DATA_COUNTERS => [],
               DEFAULT_NULL_VALUE => '0',
               COUNTER_GROUPS => {
                  C6_1_7_C12_1_7_HO_AGGREGATE_TOTAL => '.*AGGREGATE',
               },

          },

           {
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Generating LIFs',
               INPUT_FILE_DESCRIPTION => ['SCANBTS-.*-#-J-#-S-#-S-#-AL\.pif$'],
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
           },

        {
               RULE_TYPE => 'PIF_REMOVE',
               RULE_DESC => '',
               INPUT_FILE_DESCRIPTION => [ '^SCANBTSOHON-.*-PZ\.pif',
                                           '^SCANBTSOHOS-.*-PZ\.pif'],
         },

##############################################################################################################
#    Inserting CEL_ID in SCANGPRS* from SCANBTSE
#############################################################################################################

	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANGPRS',
		INPUT_FILE_DESCRIPTION => ['^SCANGPRS-#-(.*)-#-\d+-#-PM-#-.*-#-I.pif'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANGPRS',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANTRX',
		INPUT_FILE_DESCRIPTION => ['^SCANTRX-#-(.*)-#-\d+-#-PM-#-.*-#-I.pif'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANTRX',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANCTRX_CFERRXQU',
		INPUT_FILE_DESCRIPTION => ['^SCANCTRX_CFERRXQU-#-(.*)-#-\d+-#-PM-#-.*-#-I.pif'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANCTRX_CFERRXQU',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANCTRX_CRXLVQUD',
		INPUT_FILE_DESCRIPTION => ['^SCANCTRX_CRXLVQUD-#-(.*)-#-\d+-#-PM-#-.*-#-I\.pif$'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANCTRX_CRXLVQUD',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANCTRX_CRXLVQUU',
		INPUT_FILE_DESCRIPTION => ['^SCANCTRX_CRXLVQUU-#-(.*)-#-\d+-#-PM-#-.*-#-I\.pif$'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANCTRX_CRXLVQUU',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANCTRX_CRXLVTAD',
		INPUT_FILE_DESCRIPTION => ['^SCANCTRX_CRXLVTAD-#-(.*)-#-\d+-#-PM-#-.*-#-I\.pif$'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANCTRX_CRXLVTAD',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT CEL_ID TO SCANCTRX_CRXLVTAU',
		INPUT_FILE_DESCRIPTION => ['^SCANCTRX_CRXLVTAU-#-(.*)-#-\d+-#-PM-#-.*-#-I\.pif$'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => ['BSC_ID'],
		NAMES_USED_TO_ID_DATA_RECORD => ['BTSM_ID','BTS_ID'],
		INFO_FILE_DESCRIPTION => ['^SCANBTS-#-(.*)-#-\d+-#-\d+-#-J\.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => ['BSC_ID'],
		NAMES_USED_TO_ID_INFORMATION => ['BTSM_ID','BTS_ID'],
		OUTPUT_BLOCK_NAME => 'SCANCTRX_CRXLVTAU',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['CEL_ID'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
		REMOVE_INFO_FILES => 'True',
	},

        {
             RULE_TYPE => 'AGGREGATE_LINE',
             RULE_DESC => 'Aggregate C5 Counters',
             INPUT_FILE_DESCRIPTION => ['^SCANBTSOHOI-#-.*-#-I\.pif$'],
             REDUNDANT_DATA_COUNTERS => [],
             DEFAULT_NULL_VALUE => '0',
             COUNTER_GROUPS => {
                C5_1_TOTAL => 'C5_1_.*',
                C5_0_TOTAL => 'C5_0_.*',
             },
         },
	
	{	
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Generating LIFs',
               INPUT_FILE_DESCRIPTION => [
								'SCANBSC-#-.*-#-I\.pif$',
								'SCANBTSE-#-.*-#-I\.pif$',
								'SCANBTSIHO-#-.*-#-I\.pif$',
								'SCANBTSM-#-.*-#-I\.pif$',
								'SCANBTSOHOI-#-.*-#-I-#-AL\.pif$',
								'SCANBTSOHON-#-.*-#-I\.pif$',
								'SCANCHAN-#-.*-#-I\.pif$',
								'SCANSS7L-#-.*-#-I\.pif$',
								'SCANBTSOHOS-#-.*-#-I\.pif$',
								'SCANFBTSM-#-.*-#-I\.pif$',
								],
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
	       OUTPUT_FORMAT => 'LIF_Writer',
        },

#-------------------------------------------------------------------------------
);  

#-------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;
